api.currentuser.v1 package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1 package

## Subpackages

- api.currentuser.v1.permission package
  - Submodules
  - api.currentuser.v1.permission.permission module
  - Module contents

## Submodules

## api.currentuser.v1.authmethods module

Autogenerated API

`api.currentuser.v1.authmethods.` `get_current_user_methods`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List the current users valid authentication methods (PUBLIC)

  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 783, “limit”: 832, “responseCode”: 200, “count”: 710, “data”: [{“method”: “APIKEY”, “lastLoginTimestamp”: 687105888, “lastLoginIP”: “Role character painting bring.”, “initialized”: false, “settings”: {“additionalProperties”: {}}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Turn population agreement.”, “messageTemplate”: “Society bank always energy man word culture white.”, “field”: “Chance man set each culture.”, “parameter”: {}, “timestamp”: 493417742}], “currentPage”: 17, “size”: 37}

## api.currentuser.v1.functions module

Autogenerated API

`api.currentuser.v1.functions.` `get_functions`(onlyRoles: bool = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List the current user’s permission functions regardless of customer (PUBLIC)

  Return type: | `dict`
  Parameters: | onlyRoles (bool) – Only return functions marked as roles keywords (list) – Filter functions by keywords on name and description offset (int) – Skip a number of functions limit (int) – Maximum number of returned functions
  Raises: | AuthenticationFailedException – on 401 ForbiddenPermissionException – on 403
  Returns: | {“offset”: 844, “limit”: 706, “responseCode”: 200, “count”: 988, “data”: [{“id”: 137, “name”: “Kelly Bennett”, “description”: “Society nature else perhaps add want prepare.”, “securityLevel”: “DEFAULT”, “flags”: [“ROLE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Exactly get officer result green.”, “messageTemplate”: “Then defense training Republican.”, “field”: “Major radio place.”, “parameter”: {}, “timestamp”: 452244622}], “currentPage”: 62, “size”: 39}

## api.currentuser.v1.picture module

Autogenerated API

`api.currentuser.v1.picture.` `get_profile_picture`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get current user’s profile picture (PUBLIC)

  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ProfilePictureNotFoundException – on 404
  Returns: | {}

`api.currentuser.v1.picture.` `update_profile_picture`(picture: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Set current user’s profile picture (PUBLIC)

  Return type: | `dict`
  Parameters: | picture (str) – Image data url
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 787, “limit”: 587, “responseCode”: 200, “count”: 363, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Stop performance ground woman then.”, “messageTemplate”: “Show space different development believe sit.”, “field”: “Prevent nor wide effort parent able speak.”, “parameter”: {}, “timestamp”: 1276081163}], “currentPage”: 231, “size”: 385}

## api.currentuser.v1.prefs module

Autogenerated API

`api.currentuser.v1.prefs.` `delete_properties`(key: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete multiple current user’s preferences (PUBLIC)

  Return type: | `dict`
  Parameters: | key (list) – Keys to delete
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 972, “limit”: 116, “responseCode”: 200, “count”: 2, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Toward performance get provide level.”, “messageTemplate”: “Book similar forward reach actually.”, “field”: “Huge for same order.”, “parameter”: {}, “timestamp”: 598571796}], “currentPage”: 965, “size”: 556}

`api.currentuser.v1.prefs.` `delete_property`(propertyKey: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete the specified current user’s preference (PUBLIC)

  Return type: | `dict`
  Parameters: | propertyKey (str) – Preference key to delete
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 53, “limit”: 896, “responseCode”: 200, “count”: 641, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Skill those it.”, “messageTemplate”: “Draw benefit result hit brother inside.”, “field”: “Represent no way arm stand.”, “parameter”: {}, “timestamp”: 750495011}], “currentPage”: 817, “size”: 845}

`api.currentuser.v1.prefs.` `get_property`(propertyKey: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch a specific current user’ preference value (PUBLIC) Returns a the specified preference value, or null if not set

  Return type: | `dict`

`api.currentuser.v1.prefs.` `list_properties`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List all current user’s preferences (PUBLIC) Returns a dictionary of key/value pairs, defining all the users preferences

  > raises AuthenticationFailedException:
  > | on 401
  > returns: | {“offset”: 904, “limit”: 600, “responseCode”: 200, “count”: 477, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Within entire member focus stock letter attention sense.”, “messageTemplate”: “Training too drive owner become control give certain.”, “field”: “For star example fly.”, “parameter”: {}, “timestamp”: 668684667}], “currentPage”: 419, “size”: 902}

`api.currentuser.v1.prefs.` `set_properties`(body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Set the specified current user’s preferences (PUBLIC)

  Return type: | `dict`
  Parameters: | body (`str`) – Map of preference values to update
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403
  Returns: | {“offset”: 196, “limit”: 627, “responseCode”: 200, “count”: 543, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Election foot loss while toward PM wear.”, “messageTemplate”: “Source pattern much response.”, “field”: “Difference black say suggest power.”, “parameter”: {}, “timestamp”: 257301571}], “currentPage”: 71, “size”: 783}

## api.currentuser.v1.user module

Autogenerated API

`api.currentuser.v1.user.` `get_current_user`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get the object representation of the currently logged in user (PUBLIC)

  Raises: | AuthenticationFailedException – on 401
  Returns: | {“offset”: 697, “limit”: 438, “responseCode”: 200, “count”: 201, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Speech sing management phone.”, “messageTemplate”: “Somebody point kind fill recognize.”, “field”: “Thank state little word.”, “parameter”: {}, “timestamp”: 1503737445}], “currentPage”: 603, “size”: 736}

## Module contents